!
! $Id $
!
SUBROUTINE recomp_tend_co2_slope(tendencies_co2_ice_phys,tendencies_co2_ice_phys_ini,vmr_co2_gcm,vmr_co2_pem,ps_GCM_2,global_ave_press_GCM,global_ave_press_new,timelen,ngrid,nslope)

      IMPLICIT NONE

!=======================================================================
!
!  Routine that compute the evolution of the tendencie for co2 ice
!
!=======================================================================

!   arguments:
!   ----------

!   INPUT
  INTEGER, intent(in) :: timelen,ngrid,nslope
  REAL, INTENT(in) ::  vmr_co2_gcm(ngrid,timelen)                ! physical point field : Volume mixing ratio of co2 in the first layer
  REAL, INTENT(in) ::  vmr_co2_pem(ngrid,timelen)                ! physical point field : Volume mixing ratio of co2 in the first layer
  REAL, intent(in) :: ps_GCM_2(ngrid,timelen)                 ! physical point field : Surface pressure in the GCM
  REAL, intent(in) :: global_ave_press_GCM
  REAL, intent(in) :: global_ave_press_new
  REAL, intent(in) ::  tendencies_co2_ice_phys_ini(ngrid,nslope) ! physical point field : Evolution of perenial ice over one year

!   OUTPUT
  REAL, intent(inout) ::  tendencies_co2_ice_phys(ngrid,nslope) ! physical point field : Evolution of perenial ice over one year

!   local:
!   ----

  INTEGER :: i,t,islope
  REAL :: eps, sigma, L, beta, alpha, coef, ave

  eps=0.95
  sigma=5.678E-8
  L=5.71*10**5
  beta=3182.48
  alpha=23.3494

  coef=669*24*3600*eps*sigma/L

! Evolution of the water ice for each physical point
  do i=1,ngrid
    do islope=1,nslope
      ave=0.
      if(abs(tendencies_co2_ice_phys(i,islope)).gt.1e-4) then
        do t=1,timelen
           ave=ave+(beta/(alpha-log(vmr_co2_gcm(i,t)*ps_GCM_2(i,t)/100.)))**4  &
              -(beta/(alpha-log(vmr_co2_pem(i,t)*ps_GCM_2(i,t)*global_ave_press_GCM/global_ave_press_new/100.)))**4
         enddo
      endif
      if(ave.lt.1e-4) ave = 0.
      tendencies_co2_ice_phys(i,islope)=tendencies_co2_ice_phys_ini(i,islope)-coef*ave/timelen
    enddo
  enddo

END SUBROUTINE recomp_tend_co2_slope
